@@ -24,9 +24,9 @@ use std::time::SystemTime;
 
 use chrono::prelude::*;
 
-use log::*;
+use log::{debug, error, trace};
 #[cfg(unix)]
-use once_cell::sync::Lazy;
+use std::sync::LazyLock;
 
 use crate::fs::dir::Dir;
 use crate::fs::feature::xattr;
@@ -41,11 +41,10 @@ use super::mounts::MountedFs;
 // Maps (device_id, inode) => (size_in_bytes, size_in_blocks)
 // Mutex::new is const but HashMap::new is not const requiring us to use lazy
 // initialization.
-// TODO: Replace with std::sync::LazyLock when it is stable.
 #[allow(clippy::type_complexity)]
 #[cfg(unix)]
-static DIRECTORY_SIZE_CACHE: Lazy<Mutex<HashMap<(u64, u64), (u64, u64)>>> =
-    Lazy::new(|| Mutex::new(HashMap::new()));
+static DIRECTORY_SIZE_CACHE: LazyLock<Mutex<HashMap<(u64, u64), (u64, u64)>>> =
+    LazyLock::new(|| Mutex::new(HashMap::new()));
 
 /// A **File** is a wrapper around one of Rust’s `PathBuf` values, along with
 /// associated data about the file.
@@ -210,10 +209,12 @@ impl<'dir> File<'dir> {
         file
     }
 
+    #[must_use]
     pub fn new_aa_current(parent_dir: &'dir Dir, total_size: bool) -> File<'dir> {
         File::new_aa(parent_dir.path.clone(), parent_dir, ".", total_size)
     }
 
+    #[must_use]
     pub fn new_aa_parent(path: PathBuf, parent_dir: &'dir Dir, total_size: bool) -> File<'dir> {
         File::new_aa(path, parent_dir, "..", total_size)
     }
@@ -221,6 +222,7 @@ impl<'dir> File<'dir> {
     /// A file’s name is derived from its string. This needs to handle directories
     /// such as `/` or `..`, which have no `file_name` component. So instead, just
     /// use the last component as the name.
+    #[must_use]
     pub fn filename(path: &Path) -> String {
         if let Some(back) = path.components().next_back() {
             back.as_os_str().to_string_lossy().to_string()
@@ -599,9 +601,16 @@ impl<'dir> File<'dir> {
             #[allow(trivial_numeric_casts)]
             #[allow(clippy::unnecessary_cast, clippy::useless_conversion)]
             f::Size::DeviceIDs(f::DeviceIDs {
-                // SAFETY: Calling libc function to decompose the device_id
-                major: unsafe { libc::major(device_id.try_into().unwrap()) } as u32,
-                minor: unsafe { libc::minor(device_id.try_into().unwrap()) } as u32,
+                major: libc::major(
+                    device_id
+                        .try_into()
+                        .expect("Malformed device major ID when getting filesize"),
+                ) as u32,
+                minor: libc::minor(
+                    device_id
+                        .try_into()
+                        .expect("Malformed device major ID when getting filesize"),
+                ) as u32,
             })
         } else if self.is_file() {
             f::Size::Some(self.metadata().map_or(0, std::fs::Metadata::len))
@@ -1010,6 +1019,7 @@ pub enum FileTarget<'dir> {
 impl<'dir> FileTarget<'dir> {
     /// Whether this link doesn’t lead to a file, for whatever reason. This
     /// gets used to determine how to highlight the link in grid views.
+    #[must_use]
     pub fn is_broken(&self) -> bool {
         matches!(self, Self::Broken(_) | Self::Err(_))
     }
