@@ -65,12 +65,15 @@ fn main() {
     let args: Vec<_> = env::args_os().skip(1).collect();
     match Options::parse(args.iter().map(std::convert::AsRef::as_ref), &LiveVars) {
         OptionsResult::Ok(options, mut input_paths) => {
+            let mut default_input_path = false;
+
             // List the current directory by default.
             // (This has to be done here, otherwise git_options won’t see it.)
             if input_paths.is_empty() {
                 match &options.stdin {
                     FilesInput::Args => {
                         input_paths = vec![OsStr::new(".")];
+                        default_input_path = true;
                     }
                     FilesInput::Stdin(separator) => {
                         stdin()
@@ -97,6 +100,7 @@ fn main() {
                 options,
                 writer,
                 input_paths,
+                default_input_path,
                 theme,
                 console_width,
                 git,
@@ -106,7 +110,7 @@ fn main() {
             info!("matching on exa.run");
             match exa.run() {
                 Ok(exit_status) => {
-                    trace!("exa.run: exit Ok(exit_status)");
+                    trace!("exa.run: exit Ok({exit_status})");
                     exit(exit_status);
                 }
 
@@ -155,6 +159,10 @@ pub struct Exa<'args> {
     /// names (anything that isn’t an option).
     pub input_paths: Vec<&'args OsStr>,
 
+    /// If no path has been passed through with the command line, and the
+    /// `input_paths` field has been filled with "." by default
+    pub default_input_path: bool,
+
     /// The theme that has been configured from the command-line options and
     /// environment variables. If colours are disabled, this is a theme with
     /// every style set to the default.
@@ -260,33 +268,37 @@ impl<'args> Exa<'args> {
         let mut exit_status = 0;
 
         for file_path in &self.input_paths {
-            match File::from_args(
+            let f = File::from_args(
                 PathBuf::from(file_path),
                 None,
                 None,
                 self.options.view.deref_links,
                 self.options.view.total_size,
-            ) {
-                Err(e) => {
-                    exit_status = 2;
-                    writeln!(io::stderr(), "{file_path:?}: {e}")?;
-                }
+                None,
+            );
 
-                Ok(f) => {
-                    if f.points_to_directory() && !self.options.dir_action.treat_dirs_as_files() {
-                        trace!("matching on to_dir");
-                        match f.to_dir() {
-                            Ok(d) => dirs.push(d),
-                            Err(e) if e.kind() == ErrorKind::PermissionDenied => {
-                                eprintln!("{file_path:?}: {e}");
-                                exit(exits::PERMISSION_DENIED);
-                            }
-                            Err(e) => writeln!(io::stderr(), "{file_path:?}: {e}")?,
-                        }
-                    } else {
-                        files.push(f);
+            // We don't know whether this file exists, so we have to try to get
+            // the metadata to verify.
+            if let Err(e) = f.metadata() {
+                exit_status = 2;
+                writeln!(io::stderr(), "{file_path:?}: {e}")?;
+                continue;
+            }
+
+            if f.points_to_directory()
+                && (self.default_input_path || !self.options.dir_action.treat_dirs_as_files())
+            {
+                trace!("matching on to_dir");
+                match f.to_dir() {
+                    Ok(d) => dirs.push(d),
+                    Err(e) if e.kind() == ErrorKind::PermissionDenied => {
+                        eprintln!("{file_path:?}: {e}");
+                        exit(exits::PERMISSION_DENIED);
                     }
+                    Err(e) => writeln!(io::stderr(), "{file_path:?}: {e}")?,
                 }
+            } else {
+                files.push(f);
             }
         }
 
@@ -344,10 +356,7 @@ impl<'args> Exa<'args> {
                 self.options.view.deref_links,
                 self.options.view.total_size,
             ) {
-                match file {
-                    Ok(file) => children.push(file),
-                    Err((path, e)) => writeln!(io::stderr(), "[{}: {}]", path.display(), e)?,
-                }
+                children.push(file);
             }
             let recursing = self.options.dir_action.recurse_options().is_some();
             self.options
