@@ -316,6 +316,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "compose.yaml"        => Icons::DOCKER,         // 
     "compose.yml"         => Icons::DOCKER,         // 
     "docker-compose.yaml" => Icons::DOCKER,         // 
+    "dropbox"             => '\u{e707}',            // 
     "dune"                => Icons::LANG_OCAML,     // 
     "dune-project"        => Icons::WRENCH,         // 
     "Earthfile"           => '\u{f0ac}',            // 
@@ -983,6 +984,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "sublime-settings"=>Icons::SUBLIME,          // 
     "sublime-snippet"=> Icons::SUBLIME,          // 
     "sublime-theme"  => Icons::SUBLIME,          // 
+    "suo"            => '\u{e70c}',              // 
     "svelte"         => '\u{e697}',              // 
     "sv"             => Icons::LANG_HDL,         // 󰍛
     "svg"            => Icons::VECTOR,           // 󰕙
@@ -1056,6 +1058,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "xaml"           => '\u{f0673}',             // 󰙳
     "xcf"            => Icons::GIMP,             // 
     "xci"            => '\u{F07E1}',             // 󰟡
+    "xcplayground"   => '\u{e755}',              // 
     "xhtml"          => Icons::HTML5,            // 
     "xlr"            => Icons::SHEET,            // 
     "xls"            => Icons::SHEET,            // 
